Module: RobotLab::To
- Defined in:
- lib/robot_lab/to.rb,
lib/robot_lab/to/cli.rb,
lib/robot_lab/to/run.rb,
lib/robot_lab/to/config.rb,
lib/robot_lab/to/errors.rb,
lib/robot_lab/to/guards.rb,
lib/robot_lab/to/backoff.rb,
lib/robot_lab/to/version.rb,
lib/robot_lab/to/decision.rb,
lib/robot_lab/to/verifier.rb,
lib/robot_lab/to/evals/base.rb,
lib/robot_lab/to/evals/code.rb,
lib/robot_lab/to/evals/null.rb,
lib/robot_lab/to/tools/bash.rb,
lib/robot_lab/to/tools/edit.rb,
lib/robot_lab/to/tools/read.rb,
lib/robot_lab/to/atomic_file.rb,
lib/robot_lab/to/evals/prose.rb,
lib/robot_lab/to/evals/score.rb,
lib/robot_lab/to/tools/write.rb,
lib/robot_lab/to/exit_summary.rb,
lib/robot_lab/to/jsonl_logger.rb,
lib/robot_lab/to/orchestrator.rb,
lib/robot_lab/to/evals/context.rb,
lib/robot_lab/to/evals/factory.rb,
lib/robot_lab/to/notes_manager.rb,
lib/robot_lab/to/commit_manager.rb,
lib/robot_lab/to/prompt_builder.rb,
lib/robot_lab/to/stop_conditions.rb,
lib/robot_lab/to/tools/file_tool.rb,
lib/robot_lab/to/decision_manager.rb,
lib/robot_lab/to/guards/run_store.rb,
lib/robot_lab/to/iteration_result.rb,
lib/robot_lab/to/guards/checkpoint.rb,
lib/robot_lab/to/guards/grader_lock.rb,
lib/robot_lab/to/guards/write_guard.rb,
lib/robot_lab/to/tools/submit_result.rb,
lib/robot_lab/to/guards/path_resolution.rb,
lib/robot_lab/to/guards/quality_monitor.rb,
lib/robot_lab/to/tools/request_decision.rb,
lib/robot_lab/to/guards/read_before_edit.rb
Defined Under Namespace
Modules: AtomicFile, Evals, Guards, Tools Classes: AbortError, Backoff, CLI, CommitFailedError, CommitManager, Config, Decision, DecisionManager, Error, ExitSummary, IterationResult, JsonlLogger, NotesManager, Orchestrator, PermanentError, PromptBuilder, Run, StopConditions, Verifier
Constant Summary collapse
- VERSION =
"0.2.6"
Class Method Summary collapse
-
.evals ⇒ Object
Registry of named Eval strategies (see RobotLab::To::Evals.build).
- .register_eval(name, &block) ⇒ Object
-
.resume(run_id) ⇒ Object
Resume a paused run by id (used for cron/exit-mode operation).
-
.run(objective) ⇒ void
Launch an autonomous takeover run.
Class Method Details
.evals ⇒ Object
Registry of named Eval strategies (see RobotLab::To::Evals.build). The block receives the Config and returns an object responding to #score.
61 |
# File 'lib/robot_lab/to.rb', line 61 def evals = (@evals ||= {}) |
.register_eval(name, &block) ⇒ Object
63 64 65 |
# File 'lib/robot_lab/to.rb', line 63 def register_eval(name, &block) evals[name.to_sym] = block end |
.resume(run_id) ⇒ Object
Resume a paused run by id (used for cron/exit-mode operation). The objective and prior state are loaded from the run's run.json.
53 54 55 56 57 |
# File 'lib/robot_lab/to.rb', line 53 def resume(run_id, **) config = Config.new(**) suppress_llm_logging unless config.debug? Orchestrator.new(nil, config, resume_run_id: run_id).run end |
.run(objective) ⇒ void
This method returns an undefined value.
Launch an autonomous takeover run.
45 46 47 48 49 |
# File 'lib/robot_lab/to.rb', line 45 def run(objective, **) config = Config.new(**) suppress_llm_logging unless config.debug? Orchestrator.new(objective, config).run end |